@@ -1,6 +1,7 @@
-import environ
 import threading
 
+import environ
+
 env = environ.Env(DEBUG=(bool, False))
 # reading .env file
 environ.Env.read_env(env.str("ENV_PATH", ".env"))
@@ -27,7 +28,6 @@ INSTALLED_APPS = [
     "django.contrib.sessions",
     "django.contrib.messages",
     "django.contrib.staticfiles",
-    "channels",
     "rest_framework",
     "django_filters",
     "spreadsheetui",
@@ -79,9 +79,15 @@ AUTH_PASSWORD_VALIDATORS = [
     {
         "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
     },
-    {"NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",},
-    {"NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",},
-    {"NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",},
+    {
+        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
+    },
+    {
+        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
+    },
+    {
+        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
+    },
 ]
 
 
@@ -121,4 +127,4 @@ TORRENT_UPDATE_FULL_DELAY = 300
 DATABASE_LOCK = threading.Lock()
 SCHEDULER_SERVICE = None
 EXECUTE_JOBS_SERVICE = None
-TORRENT_CLIENT_UPDATERS = []
\ No newline at end of file
+TORRENT_CLIENT_UPDATERS = []
