@@ -1,7 +1,6 @@
 from django.db import models
 from jsonfield import JSONField
-
-from libtc import TORRENT_CLIENT_MAPPING, move_torrent
+from libtc import TORRENT_CLIENT_MAPPING, move_torrent, parse_libtc_url
 
 
 class TorrentClient(models.Model):
@@ -13,13 +12,19 @@ class TorrentClient(models.Model):
         choices=(
             (c.identifier, c.display_name) for c in TORRENT_CLIENT_MAPPING.values()
         ),
+        null=True,
+        blank=True,
     )
     config = JSONField()
     enabled = models.BooleanField(default=True)
 
     def get_client(self):
-        client_cls = TORRENT_CLIENT_MAPPING[self.client_type]
-        return client_cls(**self.config)
+        client_url = self.config.pop("client_url", None)
+        if client_url:
+            return parse_libtc_url(client_url)
+        else:
+            client_cls = TORRENT_CLIENT_MAPPING[self.client_type]
+            return client_cls(**self.config)
 
     def __repr__(self):
         return f"TorrentClient(name={self.name!r}, client_type={self.client_type!r}, enabled={self.enabled!r})"
@@ -45,18 +50,25 @@ class Torrent(models.Model):
 
 
 class Job(models.Model):
-    ACTION_START = 'start'
-    ACTION_STOP = 'stop'
-    ACTION_REMOVE = 'remove'
-    ACTION_MOVE = 'move'
-    action = models.CharField(max_length=20, choices=(
-        (ACTION_START, 'Start'),
-        (ACTION_STOP, 'Stop'),
-        (ACTION_REMOVE, 'Remove'),
-        (ACTION_MOVE, 'Move'),
-    ))
-    torrent = models.ForeignKey(Torrent, on_delete=models.CASCADE, null=True, related_name='+')
-    target_client = models.ForeignKey(TorrentClient, on_delete=models.CASCADE, null=True, related_name='+')
+    ACTION_START = "start"
+    ACTION_STOP = "stop"
+    ACTION_REMOVE = "remove"
+    ACTION_MOVE = "move"
+    action = models.CharField(
+        max_length=20,
+        choices=(
+            (ACTION_START, "Start"),
+            (ACTION_STOP, "Stop"),
+            (ACTION_REMOVE, "Remove"),
+            (ACTION_MOVE, "Move"),
+        ),
+    )
+    torrent = models.ForeignKey(
+        Torrent, on_delete=models.CASCADE, null=True, related_name="+"
+    )
+    target_client = models.ForeignKey(
+        TorrentClient, on_delete=models.CASCADE, null=True, related_name="+"
+    )
     config = JSONField(default={}, blank=True)
 
     can_execute = models.BooleanField(default=False)
@@ -80,4 +92,6 @@ class Job(models.Model):
             client = self.torrent.torrent_client.get_client()
             target_client = self.target_client.get_client()
             fast_resume = self.torrent.progress == 100.0
-            move_torrent(self.torrent.infohash, client, target_client, fast_resume=fast_resume)
+            move_torrent(
+                self.torrent.infohash, client, target_client, fast_resume=fast_resume
+            )
